==> haskell-hls-brittany-plugin-1.0.0.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-brittany-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-brittany-plugin
version:              1.0.0.0
visibility:           public
id:                   hls-brittany-plugin-1.0.0.0-5PxQ23fJhT2JNhcOs5epTZ
key:                  hls-brittany-plugin-1.0.0.0-5PxQ23fJhT2JNhcOs5epTZ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Brittany code formatter
category:             Development
abi:                  c2a15bcf8656458271f59d735d41eba5
exposed:              True
exposed-modules:      Ide.Plugin.Brittany
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hls-brittany-plugin-1.0.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hls-brittany-plugin-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/hls-brittany-plugin-1.0.0.0

hs-libraries:         HShls-brittany-plugin-1.0.0.0-5PxQ23fJhT2JNhcOs5epTZ
depends:
    base-4.14.1.0 brittany-0.13.1.0-26VvJKxOVPkAxQZboK5UmZ
    filepath-1.4.2.1 ghc-8.10.4 ghc-boot-th-8.10.4
    ghcide-1.1.0.0-AFOqwj6Lf9p3DYhUG7NfzO
    hls-plugin-api-1.0.0.0-EhzzvFwPgrAJd1XE4JFBdj
    lens-5-KtG5disPT0S2GVDbcUrbVF
    lsp-types-1.1.0.0-IIc1qNPSnpQ3Uh9C91eGcN text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-brittany-plugin/html/hls-brittany-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-brittany-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-brittany-plugin-1.0.0.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-brittany-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-brittany-plugin
version:              1.0.0.0
visibility:           public
id:                   hls-brittany-plugin-1.0.0.0-JqHB6Myn8jBJGe8IQVHpWr
key:                  hls-brittany-plugin-1.0.0.0-JqHB6Myn8jBJGe8IQVHpWr
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Brittany code formatter
category:             Development
abi:                  87569d8ba0fcaa88914601556a04fb78
exposed:              True
exposed-modules:      Ide.Plugin.Brittany
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hls-brittany-plugin-1.0.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hls-brittany-plugin-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/hls-brittany-plugin-1.0.0.0

hs-libraries:         HShls-brittany-plugin-1.0.0.0-JqHB6Myn8jBJGe8IQVHpWr
depends:
    base-4.14.1.0 brittany-0.13.1.1-JSJhQ2Aho2GEqL262d1SP
    filepath-1.4.2.1 ghc-8.10.4 ghc-boot-th-8.10.4
    ghcide-1.1.0.0-FDKYQMGolCWAOFdro071DP
    hls-plugin-api-1.0.0.0-A1H8BAHiioa1nTMqrkcVAg
    lens-5.0.1-GQ9qIy7F2QRLy6pB6lHgUn
    lsp-types-1.1.0.0-32SjvBKGaGqDFUTTn7RNAX text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-brittany-plugin/html/hls-brittany-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-brittany-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
